@@ -45,6 +45,9 @@ na.seadec <- function(x, algorithm = "interpolation" , ...) {
   # No imputation code in this part. 
   if (!is.null( dim(data)[2]) && dim(data)[2] > 1 ) {
     for (i in 1:dim(data)[2]) {
+      
+      if (!anyNA(data[,i])) {next}
+      
       #if imputing a column does not work (mostly because it is not numeric) the column is left unchanged
       tryCatch(data[,i] <- na.seadec(data[ ,i], algorithm, ...), error=function(cond) {
         warning(paste("imputeTS: No imputation performed for column",i,"because of this",cond), call. = FALSE)
@@ -61,10 +64,18 @@ na.seadec <- function(x, algorithm = "interpolation" , ...) {
     ## Input check
     ## 
     
+    missindx <- is.na(data)
+    
+    #Nothing to impute in the data
     if(!anyNA(data)) {
       return(data)
     }
     
+    #Input completly NA
+    if (all(missindx)) {
+      stop("Input data has only NAs")
+    }
+    
     if(!is.null(dim(data)[2])&&!dim(data)[2]==1)
     {stop("Wrong input type for parameter x")}
     
@@ -95,7 +106,6 @@ na.seadec <- function(x, algorithm = "interpolation" , ...) {
     ## Imputation Code
     ##
   
-    missindx <- is.na(data)  
     
     #approx NAs, to get complete series, because stl does not work with NAs
     temp <- na.interpolation(data)
